@@ -41,7 +41,7 @@ def sorted_imports(
                 parsed.imports[section].get("straight", {})
             )
             parsed.imports["no_sections"]["from"].update(parsed.imports[section].get("from", {}))
-        sections = base_sections + ("no_sections",)
+        sections = (*base_sections, "no_sections")
 
     output: List[str] = []
     seen_headings: Set[str] = set()
@@ -240,6 +240,9 @@ def sorted_imports(
     return _output_as_string(formatted_output, parsed.line_separator)
 
 
+# Ignore DeepSource cyclomatic complexity check for this function. It was
+# already complex when this check was enabled.
+# skipcq: PY-R1000
 def _with_from_imports(
     parsed: parse.ParsedContent,
     config: Config,
@@ -335,7 +338,7 @@ def _with_from_imports(
                     )
                     if comment:
                         single_import_line += (
-                            f"{comments and ';' or config.comment_prefix} " f"{comment}"
+                            f"{(comments and ';') or config.comment_prefix} " f"{comment}"
                         )
                     if from_import in as_imports:
                         if (
@@ -464,7 +467,7 @@ def _with_from_imports(
                             comment_prefix=config.comment_prefix,
                         )
                         single_import_line += (
-                            f"{use_comments and ';' or config.comment_prefix} " f"{comment}"
+                            f"{(use_comments and ';') or config.comment_prefix} " f"{comment}"
                         )
                         output.append(wrap.line(single_import_line, parsed.line_separator, config))
 
@@ -509,7 +512,11 @@ def _with_from_imports(
                 ):
                     do_multiline_reformat = True
 
-                if config.split_on_trailing_comma and module in parsed.trailing_commas:
+                if (
+                    import_statement
+                    and config.split_on_trailing_comma
+                    and module in parsed.trailing_commas
+                ):
                     import_statement = wrap.import_statement(
                         import_start=import_start,
                         from_imports=from_import_section,
@@ -562,7 +569,7 @@ def _with_straight_imports(
 ) -> List[str]:
     output: List[str] = []
 
-    as_imports = any((module in parsed.as_map["straight"] for module in straight_modules))
+    as_imports = any(module in parsed.as_map["straight"] for module in straight_modules)
 
     # combine_straight_imports only works for bare imports, 'as' imports not included
     if config.combine_straight_imports and not as_imports:
@@ -655,7 +662,7 @@ def _ensure_newline_before_comment(output: List[str]) -> List[str]:
     def is_comment(line: Optional[str]) -> bool:
         return line.startswith("#") if line else False
 
-    for line, prev_line in zip(output, [None] + output):  # type: ignore
+    for line, prev_line in zip(output, [None, *output]):
         if is_comment(line) and prev_line != "" and not is_comment(prev_line):
             new_output.append("")
         new_output.append(line)
@@ -665,5 +672,5 @@ def _ensure_newline_before_comment(output: List[str]) -> List[str]:
 def _with_star_comments(parsed: parse.ParsedContent, module: str, comments: List[str]) -> List[str]:
     star_comment = parsed.categorized_comments["nested"].get(module, {}).pop("*", None)
     if star_comment:
-        return comments + [star_comment]
+        return [*comments, star_comment]
     return comments
